Description Usage Arguments Value
Fits a forecasting model on each dockless_df time series in a
dockless_dfc. For non-seasonal time series, an ARIMA model will
be fitted on the log transformed data. For seasonal time series, the log
transformed data will be decomposed with STL decomposition, and an ARIMA
model will be fitted on the seasonally adjusted data.
1 2 |
data |
object of class |
auto_seasonality |
logical. If |
seasons |
if |
Returns a list of models, one for each dockless_df time series.
Each model is an object of class ARIMA for non-seasonal data and an
object of class stlm for seasonal data. Both classes come from the
forecast package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.