build_single_model: Forecasting model for 'dockless_df' object

Description Usage Arguments Value

Description

Fits a forecasting model on a dockless_df time series. If the time series is non-seasonal, an ARIMA model will be fitted on the log transformed data. If the time series is seasonal, the log transformed data will be decomposed with STL decomposition, and an ARIMA model will be fitted on the seasonally adjusted data.

Usage

1
2
build_single_model(data, auto_seasonality = TRUE, seasons = list(NULL,
  96, 672, c(96, 672)))

Arguments

data

object of class dockless_df.

auto_seasonality

logical. If TRUE, the seasonal periods of the time series will be automatically determined with time series cross-validation.

seasons

if auto_seasonality is set to TRUE: a list of different seasonal period lengths - or, in the case of multiple seasonality, combinations of seasonal periods lenghts - in time lags to be tested for in the time series cross-validation. No seasonality should be represented by NULL. If auto_seasonality is set to FALSE: the seasonal period length - or, in the case of multiple seasonality, combination of seasonal period lenghts - in time lags. No seasonality should be represented by NULL.

Value

Returns an object of class ARIMA for non-seasonal data and an object of class stlm for seasonal data. Both classes come from the forecast package.


luukvdmeer/dockless documentation built on May 10, 2019, 1:24 p.m.