create_grid: Square grid over system area

Description Usage Arguments Value

Description

Creates a square grid with given cell size over the service area of the dockless bike sharing system.

Usage

1

Arguments

area

object of class sf representing the system area.

...

further arguments passed to st_make_grid.

Value

If type is set to polygons, it returns an object of class sf containing the grid cells as square polygons. If type is set to centers it returns an object of class sf containing the grid cell centroids as points.


luukvdmeer/dockless documentation built on May 10, 2019, 1:24 p.m.