create_modelpoints: Create model points

Description Usage Arguments Value

Description

Creates an object of class sf containing the geographical locations for which the forecasting models will be build. The locations are calculated by taking, per cluster, the centroid of the grid cell centers , weighted by the usage intensity of the grid cell polygons.

Usage

1
create_modelpoints(centroids)

Arguments

centroids

all grid cell centroids as an sf object with point geometry, containing at least the attributes cluster, specifying to which cluster each grid cell centroid belongs, and intensity, specifying the number of pick-ups in the grid cell that corresponds to the grid cell centroid.

Value

Returns an object of class sf with point geometry.


luukvdmeer/dockless documentation built on May 10, 2019, 1:24 p.m.