distancedata_testpoints: Distance data for the test points

Description Usage Format

Description

The distance data for the test points, both for decomposition, as for the validation of the forecast results.

Usage

1

Format

An object of class dockless_dfc, containing 500 data frames of subclass dockless_df, with 2117 rows.

bike_id

unique identification number of the bike

time

timestamp of the observation

distance

distance to the neareast available bike, in meters


luukvdmeer/dockless documentation built on May 10, 2019, 1:24 p.m.