Description Usage Arguments Value
Clusters the dockless_df objects in a dockless_dfc with
spatially constrained hierarchical clustering.
1 | spatial_cluster(data, grid, area, K, omega = seq(0, 1, 0.1))
|
data |
object of class |
grid |
grid cells as object of class |
area |
object of class |
K |
vector of integers specifying which values of k, the number of clusters, should be tested. |
omega |
vector of values specifying which values of alpha, the mixing parameter, should be tested. |
Returns a list of 2 with one element being a numeric vector of cluster
indices that specifies for each of the given dockless_df objects to which
cluster it belongs, and the second element being the geographical outines of each
cluster, bundled in an object of class sf with polygon geometry.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.