Description Usage Arguments Value
Fits a forecasting model on a dockless_df time series. If the time
series is non-seasonal, an ARIMA model will be fitted on the log transformed
data. If the time series is seasonal, the log transformed data will be
decomposed with STL decomposition, and an ARIMA model will be fitted on the
seasonally adjusted data.
1 2 |
data |
object of class |
auto_seasonality |
logical. If |
seasons |
if |
Returns an object of class ARIMA for non-seasonal data and an
object of class stlm for seasonal data. Both classes come from the
forecast package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.