Description Usage Arguments Value
Creates a square grid with given cell size over the service area of the dockless bike sharing system.
1 | create_grid(area, ...)
|
area |
object of class |
... |
further arguments passed to |
If type is set to polygons, it returns an object
of class sf containing the grid cells as square polygons.
If type is set to centers it returns an object of
class sf containing the grid cell centroids as points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.