Description Usage Arguments Value
Creates an object of class sf containing the geographical locations
for which the forecasting models will be build. The locations are calculated
by taking, per cluster, the centroid of the grid cell centers , weighted by
the usage intensity of the grid cell polygons.
1 | create_modelpoints(centroids)
|
centroids |
all grid cell centroids as an |
Returns an object of class sf with point geometry.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.