The distance data for the test points, both for decomposition, as for the validation of the forecast results.
1 |
An object of class dockless_dfc, containing 500 data frames of subclass dockless_df, with 2117 rows.
unique identification number of the bike
timestamp of the observation
distance to the neareast available bike, in meters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.