Description Usage Arguments Value
Retrieves, for each of the given geographical locations, distances to the nearest available bike for several timestamps in the past, from the JUMP Bikes database. Database credentials are needed for this function.
1 2 3 | query_distances(locations, from = as.POSIXct("2018-09-10 16:30:00",
format = "%Y-%m-%d %H:%M:%S", tz = "America/Los_Angeles"),
to = Sys.time(), database_user, database_password)
|
locations |
object of class |
from |
timestamp of class |
to |
timestamp of class |
database_user |
character defining the user name to access the database. |
database_password |
character defining the password to access the database. |
Returns an object of class dockless_dfc, which is a collection
of data frames of class dockless_df. Each dockless_df object is
a time series of historical distance data for a specific geographical location.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.